@@ -28,10 +28,7 @@ function sha256sum(p) {
   });
 }
 
-async function download(url, dest) {
-  const agent = {};
-  agent.https = process.env.HTTPS_PROXY ? new HttpsProxyAgent({proxy: process.env.HTTPS_PROXY}): undefined;
-  agent.http = process.env.HTTP_PROXY ? new HttpProxyAgent({proxy: process.env.HTTP_PROXY}): undefined;
+async function download(url, dest, agent) {
   console.log(`download ${url}`);
   await pipeline(
     got.stream(url, { agent }),
@@ -48,11 +45,15 @@ async function download(url, dest) {
   }
   mkdirp(dir);
 
-  const bin = path.join(dir, 'main');
+  const bin = path.join(dir, 'bootstrap');
 
   if (!fs.existsSync(bin)) {
-    await download(`${rootUrl}/releases/download/v${version}/main`, bin);
-    const expectedIntegrity = (await got(`${rootUrl}/releases/download/v${version}/main.sha256`)).body.trim();
+    const agent = {};
+    agent.https = process.env.HTTPS_PROXY ? new HttpsProxyAgent({proxy: process.env.HTTPS_PROXY}): undefined;
+    agent.http = process.env.HTTP_PROXY ? new HttpProxyAgent({proxy: process.env.HTTP_PROXY}): undefined;
+
+    await download(`${rootUrl}/releases/download/v${version}/bootstrap`, bin, agent);
+    const expectedIntegrity = (await got(`${rootUrl}/releases/download/v${version}/bootstrap.sha256`, { agent })).body.trim();
     const integrity = await sha256sum(bin);
 
     if (integrity !== expectedIntegrity) {
@@ -63,4 +64,4 @@ async function download(url, dest) {
 })().catch(err => {
   console.error(err.toString());
   process.exit(1);
-})
\ No newline at end of file
+})
