@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -8,11 +11,16 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-ecr-deployment", "2.5.6", __name__[0:-6], "cdk-ecr-deployment@2.5.6.jsii.tgz"
+    "cdk-ecr-deployment",
+    "3.0.55",
+    __name__[0:-6],
+    "cdk-ecr-deployment@3.0.55.jsii.tgz",
 )
 
 __all__ = [
